Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(822)

Unified Diff: pydir/szbuild.py

Issue 956123002: Subzero: Change the name llvm2ice to the more appropriate pnacl-sz. (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: Make comment correct Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« README.rst ('K') | « pydir/run-pnacl-sz.py ('k') | src/IceGlobalInits.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pydir/szbuild.py
diff --git a/pydir/szbuild.py b/pydir/szbuild.py
index cad4e7d519a03e0b12349acf0a4f1bf90065cf6a..eaba32b216fcce3d294d2f860f592faff3ccad77 100755
--- a/pydir/szbuild.py
+++ b/pydir/szbuild.py
@@ -121,7 +121,7 @@ def main():
entirely using Subzero, without using llc or linker tricks.
This script uses file modification timestamps to determine whether llc and
Subzero re-translation are needed. It checks timestamps of llc, llvm2ice,
and the pexe against the translated object files to determine the minimal
work necessary. The --force option suppresses those checks and
re-translates everything.
@@ -169,8 +169,8 @@ def ProcessPexe(args, pexe, exe):
sym_sz_unescaped = pexe_base_unescaped + '.sym.sz.txt'
whitelist_sz = pexe_base + '.wl.sz.txt'
whitelist_sz_unescaped = pexe_base_unescaped + '.wl.sz.txt'
- llvm2ice = (
- '{root}/toolchain_build/src/subzero/llvm2ice'
+ pnacl_sz = (
+ '{root}/toolchain_build/src/subzero/pnacl-sz'
).format(root=nacl_root)
llcbin = 'llc'
gold = 'le32-nacl-ld.gold'
@@ -206,9 +206,9 @@ def ProcessPexe(args, pexe, exe):
if (args.force or
NewerThanOrNotThere(pexe, obj_sz) or
- NewerThanOrNotThere(llvm2ice, obj_sz)):
- # Run llvm2ice regardless of hybrid mode.
- shellcmd([llvm2ice,
+ NewerThanOrNotThere(pnacl_sz, obj_sz)):
+ # Run pnacl-sz regardless of hybrid mode.
+ shellcmd([pnacl_sz,
'-O' + opt_level,
'-bitcode-format=pnacl',
'-filetype=' + args.filetype,
@@ -121,7 +121,7 @@ def main():
entirely using Subzero, without using llc or linker tricks.
This script uses file modification timestamps to determine whether llc and
- Subzero re-translation are needed. It checks timestamps of llc, llvm2ice,
+ Subzero re-translation are needed. It checks timestamps of llc, pnacl-sz,
and the pexe against the translated object files to determine the minimal
work necessary. The --force option suppresses those checks and
« README.rst ('K') | « pydir/run-pnacl-sz.py ('k') | src/IceGlobalInits.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698